attempt to regularize atoi mess.
diff --git a/console-tools/openvt.c b/console-tools/openvt.c
index 0c0cef2..f1cf564 100644
--- a/console-tools/openvt.c
+++ b/console-tools/openvt.c
@@ -10,14 +10,6 @@
 
 /* getopt not needed */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <unistd.h>
-#include <fcntl.h>
-#include <string.h>
-#include <sys/types.h>
-#include <ctype.h>
-
 #include "busybox.h"
 
 int openvt_main(int argc, char **argv)
@@ -29,8 +21,8 @@
 	if (argc < 3) {
 		bb_show_usage();
 	}
-	/* check for Illegal vt number: < 1 or > 12 */
-	sprintf(vtname, VC_FORMAT, (int)bb_xgetlarg(argv[1], 10, 1, 12));
+	/* check for illegal vt number: < 1 or > 63 */
+	sprintf(vtname, VC_FORMAT, (int)xatoul_range(argv[1], 1, 63));
 
 	if (fork() == 0) {
 		/* leave current vt */